@@ -6,6 +6,7 @@ import numpy as np
 from aug_sfutils import sfdics, str_byt
 
 logger = logging.getLogger('aug_sfutils.ww')
+logger.setLevel(logging.INFO)
 
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
 if not os.path.isfile(wwlib):
@@ -133,6 +134,7 @@ class WW:
             _format  = ct.byref(format)
             _indices = ct.byref(c_indices)
 
+            logger.debug(signame)
             result = libddww.wwoinfo_(_error, self._diaref, name, _typ, \
                      _format, _ntval, _items, _indices, lname)
 
